@@ -69,10 +69,22 @@ class Configuration:
         jars_key = jvm.org.apache.flink.configuration.PipelineOptions.JARS.key()
         classpaths_key = jvm.org.apache.flink.configuration.PipelineOptions.CLASSPATHS.key()
         if key in [jars_key, classpaths_key]:
-            add_jars_to_context_class_loader(value.split(";"))
+            jar_urls = Configuration.parse_jars_value(value, jvm)
+            add_jars_to_context_class_loader(jar_urls)
         self._j_configuration.setString(key, value)
         return self
 
+    @staticmethod
+    def parse_jars_value(value: str, jvm):
+        is_standard_yaml = jvm.org.apache.flink.configuration.GlobalConfiguration.isStandardYaml()
+        if is_standard_yaml:
+            from ruamel.yaml import YAML
+            yaml = YAML(typ='safe')
+            jar_urls_list = yaml.load(value)
+            if isinstance(jar_urls_list, list):
+                return jar_urls_list
+        return value.split(";")
+
     def get_integer(self, key: str, default_value: int) -> int:
         """
         Returns the value associated with the given key as an integer.
