@@ -15,10 +15,12 @@
 #  See the License for the specific language governing permissions and
 # limitations under the License.
 ################################################################################
+import warnings
 from enum import Enum
 from typing import Optional
 
 from pyflink.common import Duration
+from pyflink.datastream.checkpoint_storage import CheckpointStorage, _from_j_checkpoint_storage
 from pyflink.datastream.checkpointing_mode import CheckpointingMode
 from pyflink.java_gateway import get_gateway
 
@@ -213,11 +215,42 @@ class CheckpointConfig(object):
         self._j_checkpoint_config.setFailOnCheckpointingErrors(fail_on_checkpointing_errors)
         return self
 
+    def get_tolerable_checkpoint_failure_number(self) -> int:
+        """
+        Get the defined number of consecutive checkpoint failures that will be tolerated, before the
+        whole job is failed over.
+
+        :return: The maximum number of tolerated checkpoint failures.
+        """
+        return self._j_checkpoint_config.getTolerableCheckpointFailureNumber()
+
+    def set_tolerable_checkpoint_failure_number(self,
+                                                tolerable_checkpoint_failure_number: int
+                                                ) -> 'CheckpointConfig':
+        """
+        This defines how many consecutive checkpoint failures will be tolerated, before the whole
+        job is failed over. The default value is `0`, which means no checkpoint failures will be
+        tolerated, and the job will fail on first reported checkpoint failure.
+
+        Example:
+        ::
+
+            >>> config.set_tolerable_checkpoint_failure_number(2)
+
+        :param tolerable_checkpoint_failure_number: The maximum number of tolerated checkpoint
+                                                    failures.
+        """
+        self._j_checkpoint_config.setTolerableCheckpointFailureNumber(
+            tolerable_checkpoint_failure_number)
+        return self
+
     def enable_externalized_checkpoints(
             self,
             cleanup_mode: 'ExternalizedCheckpointCleanup') -> 'CheckpointConfig':
         """
-        Enables checkpoints to be persisted externally.
+        Sets the mode for externalized checkpoint clean-up. Externalized checkpoints will be enabled
+        automatically unless the mode is set to
+        :data:`ExternalizedCheckpointCleanup.NO_EXTERNALIZED_CHECKPOINTS`.
 
         Externalized checkpoints write their meta data out to persistent storage and are **not**
         automatically cleaned up when the owning job fails or is suspended (terminating with job
@@ -226,7 +259,7 @@ class CheckpointConfig(object):
 
         The :class:`ExternalizedCheckpointCleanup` mode defines how an externalized checkpoint
         should be cleaned up on job cancellation. If you choose to retain externalized checkpoints
-        on cancellation you have you handle checkpoint clean up manually when you cancel the job as
+        on cancellation you have to handle checkpoint clean-up manually when you cancel the job as
         well (terminating with job status ``CANCELED``).
 
         The target directory for externalized checkpoints is configured via
@@ -238,14 +271,53 @@ class CheckpointConfig(object):
             >>> config.enable_externalized_checkpoints(
             ...     ExternalizedCheckpointCleanup.RETAIN_ON_CANCELLATION)
 
-        :param cleanup_mode: Externalized checkpoint cleanup behaviour, the mode could be
-                             :data:`ExternalizedCheckpointCleanup.DELETE_ON_CANCELLATION` or
-                             :data:`ExternalizedCheckpointCleanup.RETAIN_ON_CANCELLATION`
+        :param cleanup_mode: Externalized checkpoint clean-up behaviour, the mode could be
+                             :data:`ExternalizedCheckpointCleanup.DELETE_ON_CANCELLATION`,
+                             :data:`ExternalizedCheckpointCleanup.RETAIN_ON_CANCELLATION` or
+                             :data:`ExternalizedCheckpointCleanup.NO_EXTERNALIZED_CHECKPOINTS`
+
+        .. note:: Deprecated in 1.15. Use :func:`set_externalized_checkpoint_cleanup` instead.
         """
         self._j_checkpoint_config.enableExternalizedCheckpoints(
             ExternalizedCheckpointCleanup._to_j_externalized_checkpoint_cleanup(cleanup_mode))
         return self
 
+    def set_externalized_checkpoint_cleanup(
+            self,
+            cleanup_mode: 'ExternalizedCheckpointCleanup') -> 'CheckpointConfig':
+        """
+        Sets the mode for externalized checkpoint clean-up. Externalized checkpoints will be enabled
+        automatically unless the mode is set to
+        :data:`ExternalizedCheckpointCleanup.NO_EXTERNALIZED_CHECKPOINTS`.
+
+        Externalized checkpoints write their meta data out to persistent storage and are **not**
+        automatically cleaned up when the owning job fails or is suspended (terminating with job
+        status ``FAILED`` or ``SUSPENDED``). In this case, you have to manually clean up the
+        checkpoint state, both the meta data and actual program state.
+
+        The :class:`ExternalizedCheckpointCleanup` mode defines how an externalized checkpoint
+        should be cleaned up on job cancellation. If you choose to retain externalized checkpoints
+        on cancellation you have to handle checkpoint clean-up manually when you cancel the job as
+        well (terminating with job status ``CANCELED``).
+
+        The target directory for externalized checkpoints is configured via
+        ``org.apache.flink.configuration.CheckpointingOptions#CHECKPOINTS_DIRECTORY``.
+
+        Example:
+        ::
+
+            >>> config.set_externalized_checkpoint_cleanup(
+            ...     ExternalizedCheckpointCleanup.RETAIN_ON_CANCELLATION)
+
+        :param cleanup_mode: Externalized checkpoint clean-up behaviour, the mode could be
+                             :data:`ExternalizedCheckpointCleanup.DELETE_ON_CANCELLATION`,
+                             :data:`ExternalizedCheckpointCleanup.RETAIN_ON_CANCELLATION` or
+                             :data:`ExternalizedCheckpointCleanup.NO_EXTERNALIZED_CHECKPOINTS`
+        """
+        self._j_checkpoint_config.setExternalizedCheckpointCleanup(
+            ExternalizedCheckpointCleanup._to_j_externalized_checkpoint_cleanup(cleanup_mode))
+        return self
+
     def is_externalized_checkpoints_enabled(self) -> bool:
         """
         Returns whether checkpoints should be persisted externally.
@@ -254,28 +326,6 @@ class CheckpointConfig(object):
         """
         return self._j_checkpoint_config.isExternalizedCheckpointsEnabled()
 
-    def is_prefer_checkpoint_for_recovery(self) -> bool:
-        """
-        Returns whether a job recovery should fallback to checkpoint when there is a more recent
-        savepoint.
-
-        :return: ``True`` if a job recovery should fallback to checkpoint, false otherwise.
-        """
-        return self._j_checkpoint_config.isPreferCheckpointForRecovery()
-
-    def set_prefer_checkpoint_for_recovery(
-            self,
-            prefer_checkpoint_for_recovery: bool) -> 'CheckpointConfig':
-        """
-        Sets whether a job recovery should fallback to checkpoint when there is a more recent
-        savepoint.
-
-        :param prefer_checkpoint_for_recovery: ``True`` if a job recovery should fallback to
-                                               checkpoint, false otherwise.
-        """
-        self._j_checkpoint_config.setPreferCheckpointForRecovery(prefer_checkpoint_for_recovery)
-        return self
-
     def get_externalized_checkpoint_cleanup(self) -> Optional['ExternalizedCheckpointCleanup']:
         """
         Returns the cleanup behaviour for externalized checkpoints.
@@ -376,6 +426,65 @@ class CheckpointConfig(object):
         """
         return self._j_checkpoint_config.isForceUnalignedCheckpoints()
 
+    def set_checkpoint_storage(self, storage: CheckpointStorage) -> 'CheckpointConfig':
+        """
+        Checkpoint storage defines how stat backends checkpoint their state for fault
+        tolerance in streaming applications. Various implementations store their checkpoints
+        in different fashions and have different requirements and availability guarantees.
+
+        For example, `JobManagerCheckpointStorage` stores checkpoints in the memory of the
+        JobManager. It is lightweight and without additional dependencies but is not highly
+        available and only supports small state sizes. This checkpoint storage policy is convenient
+        for local testing and development.
+
+        The `FileSystemCheckpointStorage` stores checkpoints in a filesystem. For systems like
+        HDFS, NFS Drivs, S3, and GCS, this storage policy supports large state size, in the
+        magnitude of many terabytes while providing a highly available foundation for stateful
+        applications. This checkpoint storage policy is recommended for most production deployments.
+
+        .. note:: Deprecated since version 1.19: This method is deprecated and will be removed in
+                  future FLINK major version. Use `stream_execution_environment.configure` method
+                  instead to set the checkpoint storage.
+        """
+        warnings.warn("Deprecated since version 1.19: This method is deprecated and will be removed"
+                      " in future FLINK major version. Use `stream_execution_environment.configure`"
+                      " method instead to set the checkpoint storage.", DeprecationWarning)
+        self._j_checkpoint_config.setCheckpointStorage(storage._j_checkpoint_storage)
+        return self
+
+    def set_checkpoint_storage_dir(self, checkpoint_path: str) -> 'CheckpointConfig':
+        """
+        Configures the application to write out checkpoint snapshots to the configured directory.
+        See `FileSystemCheckpointStorage` for more details on checkpointing to a file system.
+
+        .. note:: Deprecated since version 1.19: This method is deprecated and will be removed in
+                  future FLINK major version. Use `stream_execution_environment.configure` method
+                  instead to set the checkpoint storage.
+        """
+        warnings.warn("Deprecated since version 1.19: This method is deprecated and will be removed"
+                      " in future FLINK major version. Use `stream_execution_environment.configure`"
+                      " method instead to set the checkpoint storage.", DeprecationWarning)
+        self._j_checkpoint_config.setCheckpointStorage(checkpoint_path)
+        return self
+
+    def get_checkpoint_storage(self) -> Optional[CheckpointStorage]:
+        """
+        The checkpoint storage that has been configured for the Job, or None if
+        none has been set.
+
+        .. note:: Deprecated since version 1.19: This method is deprecated and will be removed in
+                  future FLINK major version. It is recommended to find which checkpoint storage is
+                  used by checkpoint storage ConfigOption.
+        """
+        warnings.warn("Deprecated since version 1.19: This method is deprecated and will be removed"
+                      " in future FLINK major version. It is recommended to find which checkpoint"
+                      " storage is used by checkpoint storage ConfigOption.", DeprecationWarning)
+        j_storage = self._j_checkpoint_config.getCheckpointStorage()
+        if j_storage is None:
+            return None
+        else:
+            return _from_j_checkpoint_storage(j_storage)
+
 
 class ExternalizedCheckpointCleanup(Enum):
     """
@@ -403,12 +512,18 @@ class ExternalizedCheckpointCleanup(Enum):
 
     Note that checkpoint state is always kept if the job terminates
     with state ``FAILED``.
+
+    :data:`NO_EXTERNALIZED_CHECKPOINTS`:
+
+    Externalized checkpoints are disabled completely.
     """
 
     DELETE_ON_CANCELLATION = 0
 
     RETAIN_ON_CANCELLATION = 1
 
+    NO_EXTERNALIZED_CHECKPOINTS = 2
+
     @staticmethod
     def _from_j_externalized_checkpoint_cleanup(j_cleanup_mode) \
             -> 'ExternalizedCheckpointCleanup':
